.. _firebird_toplevel:

Firebird
========

.. automodule:: sqlalchemy.dialects.firebird.base

kinterbasdb
-----------

.. automodule:: sqlalchemy.dialects.firebird.kinterbasdb

fdb
---

.. automodule:: sqlalchemy.dialects.firebird.fdb
